@@ -4,9 +4,16 @@ import sys
 import types
 import typing
 import warnings
-
 from .utils import issubclass_safe
 
+try:
+    import dateutil.parser
+    assert dateutil.parser
+    HAS_DATEUTIL = True
+except Exception:
+    HAS_DATEUTIL = False
+
+
 _FROM = 1
 _TO = 2
 
@@ -125,6 +132,9 @@ def _from_dict_source(cls):
         '    args = []',
     ]
 
+    if HAS_DATEUTIL:
+        lines.insert(1, '    import dateutil.parser')
+
     fields_by_name = {f.name: f for f in dataclass_fields(cls)}
 
     for name, field_type in typing.get_type_hints(cls).items():
@@ -272,7 +282,7 @@ def expr_builder(t: type, depth=0, direction=_FROM):
             return f'{inner(t0)} if ({t0}:=({expr})) is not None else None'
 
         return f
-    elif origin == list:
+    elif origin == list and typing.get_args(t):
         type_arg = typing.get_args(t)[0]
         inner = expr_builder(type_arg, depth + 1, direction)
 
@@ -280,7 +290,7 @@ def expr_builder(t: type, depth=0, direction=_FROM):
             t0 = f'__{depth}'
             return f'[{inner(t0)} for {t0} in {expr}]'
         return f
-    elif origin == dict:
+    elif origin == dict and typing.get_args(t):
         key_type, value_type = typing.get_args(t)
 
         if not issubclass_safe(key_type, str):
@@ -332,10 +342,14 @@ def expr_builder(t: type, depth=0, direction=_FROM):
         if direction == _FROM:
             def f(expr):
                 t0 = f'__{depth}'
-                return (f'{t.__name__}.fromisoformat('
-                        f'{t0}[:-1]+"+00:00" if ({t0}:={expr})[-1]=="Z" '
-                        f'else {t0}'
-                        ')')
+                if HAS_DATEUTIL:
+                    # doesn't work for subclasses... but
+                    return f'dateutil.parser.isoparse({expr})'
+                else:
+                    return (f'{t.__name__}.fromisoformat('
+                            f'{t0}[:-1]+"+00:00" if ({t0}:={expr})[-1]=="Z" '
+                            f'else {t0}'
+                            ')')
             return f
         else:
             return lambda expr: f'({expr}).isoformat()'
@@ -370,10 +384,10 @@ def referenced_types(cls):
 
     def extract_type(t):
         origin = typing.get_origin(t)
-        if origin == typing.Union or origin == list:
+        if (origin == typing.Union or origin == list) and typing.get_args(t):
             type_arg = typing.get_args(t)[0]
             return extract_type(type_arg)
-        elif origin == dict:
+        elif origin == dict and typing.get_args(t):
             value_type_arg = typing.get_args(t)[1]
             return extract_type(value_type_arg)
         elif is_dataclass(t) or issubclass_safe(
